pick_device_for_cap

Function pick_device_for_cap 

async fn pick_device_for_cap(
    atlas: &mut AtlasClient,
    terminal: &mut Terminal<CrosstermBackend<Stdout>>,
    provider_id: &str,
    label: &str,
    kind: &str,
    saved_device_id: Option<&str>,
    mode: PickMode,
) -> Result<String>
Connect to provider_id’s list_devices capability, ask for the device list, run a picker on the entries that match kind (input/output)

  • duplex. Returns “” when the impl doesn’t expose the contract.