fn contract_llm_callable(contract: &ContractDescriptor) -> boolExpand description
Interpret absent metadata as visible for compatibility with older Atlas
processes, whose wire descriptor predates llm_callable.
fn contract_llm_callable(contract: &ContractDescriptor) -> boolInterpret absent metadata as visible for compatibility with older Atlas
processes, whose wire descriptor predates llm_callable.