pub struct GetAudioBridgeInfoResponse {
pub reverse: bool,
pub endpoint: String,
pub connected: bool,
pub detail: String,
}Fields
reverse: boolendpoint: Stringconnected: booldetail: StringTrait Implementations
Sourceimpl Clone for GetAudioBridgeInfoResponse
impl Clone for GetAudioBridgeInfoResponse
Sourcefn clone(&self) -> GetAudioBridgeInfoResponse
fn clone(&self) -> GetAudioBridgeInfoResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetAudioBridgeInfoResponse
impl Debug for GetAudioBridgeInfoResponse
Sourceimpl Default for GetAudioBridgeInfoResponse
impl Default for GetAudioBridgeInfoResponse
Sourceimpl Hash for GetAudioBridgeInfoResponse
impl Hash for GetAudioBridgeInfoResponse
Sourceimpl Message for GetAudioBridgeInfoResponse
impl Message for GetAudioBridgeInfoResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GetAudioBridgeInfoResponse
impl PartialEq for GetAudioBridgeInfoResponse
Sourcefn eq(&self, other: &GetAudioBridgeInfoResponse) -> bool
fn eq(&self, other: &GetAudioBridgeInfoResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for GetAudioBridgeInfoResponse
impl StructuralPartialEq for GetAudioBridgeInfoResponse