pub struct GetHandsfreeStatusResponse {
pub enabled: bool,
pub state: String,
pub keyword: String,
pub mic_provider_id: String,
pub speaker_provider_id: String,
pub last_wake_ms: u64,
pub last_transcript: String,
pub last_error: String,
}Fields
enabled: boolstate: Stringkeyword: Stringmic_provider_id: Stringspeaker_provider_id: Stringlast_wake_ms: u64last_transcript: Stringlast_error: StringTrait Implementations
Sourceimpl Clone for GetHandsfreeStatusResponse
impl Clone for GetHandsfreeStatusResponse
Sourcefn clone(&self) -> GetHandsfreeStatusResponse
fn clone(&self) -> GetHandsfreeStatusResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetHandsfreeStatusResponse
impl Debug for GetHandsfreeStatusResponse
Sourceimpl Default for GetHandsfreeStatusResponse
impl Default for GetHandsfreeStatusResponse
Sourceimpl Hash for GetHandsfreeStatusResponse
impl Hash for GetHandsfreeStatusResponse
Sourceimpl Message for GetHandsfreeStatusResponse
impl Message for GetHandsfreeStatusResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GetHandsfreeStatusResponse
impl PartialEq for GetHandsfreeStatusResponse
Sourcefn eq(&self, other: &GetHandsfreeStatusResponse) -> bool
fn eq(&self, other: &GetHandsfreeStatusResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for GetHandsfreeStatusResponse
impl StructuralPartialEq for GetHandsfreeStatusResponse