pub struct ModuleHealth {
pub module_key: String,
pub module_id: String,
pub provider_id: String,
pub health: u32,
pub state: String,
pub reason_code: String,
pub detail: String,
pub source: String,
pub received_ts_ns: u64,
pub ttl_ms: u32,
}Fields
module_key: Stringmodule_id: Stringprovider_id: Stringhealth: u32state: Stringreason_code: Stringdetail: Stringsource: Stringreceived_ts_ns: u64ttl_ms: u32Trait Implementations
Sourceimpl Clone for ModuleHealth
impl Clone for ModuleHealth
Sourcefn clone(&self) -> ModuleHealth
fn clone(&self) -> ModuleHealth
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleHealth
impl Debug for ModuleHealth
Sourceimpl Default for ModuleHealth
impl Default for ModuleHealth
Sourceimpl Hash for ModuleHealth
impl Hash for ModuleHealth
Sourceimpl Message for ModuleHealth
impl Message for ModuleHealth
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ModuleHealth
impl PartialEq for ModuleHealth
Sourcefn eq(&self, other: &ModuleHealth) -> bool
fn eq(&self, other: &ModuleHealth) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ModuleHealth
impl StructuralPartialEq for ModuleHealth