pub struct RtdlNodeState {
pub plan_id: String,
pub node_index: u32,
pub node_kind: u32,
pub state: u32,
pub operator_detail: String,
pub leaf_result: Option<CapabilityCallResult>,
pub op_id: String,
pub description: String,
}Fields
plan_id: Stringnode_index: u32node_kind: u32state: u32operator_detail: Stringleaf_result: Option<CapabilityCallResult>op_id: Stringdescription: StringTrait Implementations
Sourceimpl Clone for RtdlNodeState
impl Clone for RtdlNodeState
Sourcefn clone(&self) -> RtdlNodeState
fn clone(&self) -> RtdlNodeState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RtdlNodeState
impl Debug for RtdlNodeState
Sourceimpl Default for RtdlNodeState
impl Default for RtdlNodeState
Sourceimpl Hash for RtdlNodeState
impl Hash for RtdlNodeState
Sourceimpl Message for RtdlNodeState
impl Message for RtdlNodeState
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RtdlNodeState
impl PartialEq for RtdlNodeState
Sourcefn eq(&self, other: &RtdlNodeState) -> bool
fn eq(&self, other: &RtdlNodeState) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for RtdlNodeState
impl StructuralPartialEq for RtdlNodeState