pub struct ActuatorState {Show 15 fields
pub component_id: String,
pub joint_name: String,
pub position: Option<Scalar>,
pub velocity: Option<Scalar>,
pub effort: Option<Scalar>,
pub current: Option<Scalar>,
pub voltage: Option<Scalar>,
pub motor_temp: Option<Scalar>,
pub driver_temp: Option<Scalar>,
pub torque_enabled: bool,
pub brake_engaged: bool,
pub communication_ok: bool,
pub vendor_mode: u32,
pub vendor_error_code: u32,
pub status_flags: u32,
}Fields
component_id: Stringjoint_name: Stringposition: Option<Scalar>velocity: Option<Scalar>effort: Option<Scalar>current: Option<Scalar>voltage: Option<Scalar>motor_temp: Option<Scalar>driver_temp: Option<Scalar>torque_enabled: boolbrake_engaged: boolcommunication_ok: boolvendor_mode: u32vendor_error_code: u32status_flags: u32Trait Implementations
Sourceimpl Clone for ActuatorState
impl Clone for ActuatorState
Sourcefn clone(&self) -> ActuatorState
fn clone(&self) -> ActuatorState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActuatorState
impl Debug for ActuatorState
Sourceimpl Default for ActuatorState
impl Default for ActuatorState
Sourceimpl Message for ActuatorState
impl Message for ActuatorState
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ActuatorState
impl PartialEq for ActuatorState
Sourcefn eq(&self, other: &ActuatorState) -> bool
fn eq(&self, other: &ActuatorState) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ActuatorState