pub struct FaultState {
pub component_id: String,
pub fault_id: String,
pub severity: u32,
pub active: bool,
pub clearable: bool,
pub onset_ts_ns: i64,
pub vendor_code: u32,
pub vendor_code_text: String,
pub message: String,
pub attributes: Vec<String>,
pub vendor_raw_json: String,
}Fields
component_id: Stringfault_id: Stringseverity: u32active: boolclearable: boolonset_ts_ns: i64vendor_code: u32vendor_code_text: Stringmessage: Stringattributes: Vec<String>vendor_raw_json: StringTrait Implementations
Sourceimpl Clone for FaultState
impl Clone for FaultState
Sourcefn clone(&self) -> FaultState
fn clone(&self) -> FaultState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FaultState
impl Debug for FaultState
Sourceimpl Default for FaultState
impl Default for FaultState
Sourceimpl Hash for FaultState
impl Hash for FaultState
Sourceimpl Message for FaultState
impl Message for FaultState
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for FaultState
impl PartialEq for FaultState
Sourcefn eq(&self, other: &FaultState) -> bool
fn eq(&self, other: &FaultState) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for FaultState
impl StructuralPartialEq for FaultState