pub struct SomaHealthSnapshot {Show 13 fields
pub schema_version: u32,
pub body_id: String,
pub seq: u64,
pub source_ts_ns: i64,
pub soma_ts_ns: i64,
pub ttl_ms: u32,
pub components: Vec<ComponentStatus>,
pub actuators: Vec<ActuatorState>,
pub power_sources: Vec<PowerSourceState>,
pub safety: Option<SafetyState>,
pub safety_endpoints: Vec<SafetyEndpointState>,
pub faults: Vec<FaultState>,
pub metrics: Vec<Metric>,
}Fields
schema_version: u32body_id: Stringseq: u64source_ts_ns: i64soma_ts_ns: i64ttl_ms: u32components: Vec<ComponentStatus>actuators: Vec<ActuatorState>power_sources: Vec<PowerSourceState>safety: Option<SafetyState>safety_endpoints: Vec<SafetyEndpointState>faults: Vec<FaultState>metrics: Vec<Metric>Trait Implementations
Sourceimpl Clone for SomaHealthSnapshot
impl Clone for SomaHealthSnapshot
Sourcefn clone(&self) -> SomaHealthSnapshot
fn clone(&self) -> SomaHealthSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SomaHealthSnapshot
impl Debug for SomaHealthSnapshot
Sourceimpl Default for SomaHealthSnapshot
impl Default for SomaHealthSnapshot
Sourceimpl Message for SomaHealthSnapshot
impl Message for SomaHealthSnapshot
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SomaHealthSnapshot
impl PartialEq for SomaHealthSnapshot
Sourcefn eq(&self, other: &SomaHealthSnapshot) -> bool
fn eq(&self, other: &SomaHealthSnapshot) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SomaHealthSnapshot